@@ -51,7 +51,7 @@ class LIBSAMPLE_API ObjectType
 {
 public:
 
-    ObjectType(ObjectType* parent = 0);
+    explicit ObjectType(ObjectType* parent = 0);
     virtual ~ObjectType();
 
     // factory method
@@ -78,6 +78,9 @@ public:
     virtual bool event(Event* event);
     static int processEvent(ObjectTypeList objects, Event *event);
 
+    void callInvalidateEvent(Event* event);
+    virtual void invalidateEvent(Event* event) {}
+
     // This nonsense method emulate QWidget.setLayout method
     // All layout objects will became children of this object.
     void setLayout(ObjectTypeLayout* layout);
@@ -94,11 +97,15 @@ public:
     void setObjectNameWithSize(const char*, int size=9, const Str& name = Str("<unknown>"));
     void setObjectNameWithSize(const Str& name = Str("<unknown>"), int size=9);
 
-    //Function used to comfuse the generator when two values accept Null as arg
+    //Function used to confuse the generator when two values accept Null as arg
     void setObject(ObjectType *);
     void setObject(const Null&);
     int callId() const;
 
+    //Function used to create a parent from C++
+    virtual bool isPython() { return false; }
+    void callVirtualCreateChild();
+    virtual ObjectType* createChild(ObjectType* parent);
 
 private:
     ObjectType(const ObjectType&);
