@@ -26,8 +26,11 @@
 
 '''Test cases for Python representation of C++ enums.'''
 
+import os
+import sys
 import unittest
 
+import sample
 from sample import SampleNamespace, ObjectType, Event
 
 class EnumTest(unittest.TestCase):
@@ -57,6 +60,7 @@ class EnumTest(unittest.TestCase):
         '''Conversion of enum objects from Python to C++ back again.'''
         enumout = SampleNamespace.enumInEnumOut(SampleNamespace.TwoIn)
         self.assert_(enumout, SampleNamespace.TwoOut)
+        self.assertEqual(repr(enumout), repr(SampleNamespace.TwoOut))
 
     def testEnumConstructorWithTooManyParameters(self):
         '''Calling the constructor of non-extensible enum with the wrong number of parameters.'''
@@ -72,6 +76,37 @@ class EnumTest(unittest.TestCase):
         self.assertEqual(SampleNamespace.enumItemAsDefaultValueToIntArgument(SampleNamespace.ZeroOut), SampleNamespace.ZeroOut)
         self.assertEqual(SampleNamespace.enumItemAsDefaultValueToIntArgument(123), 123)
 
+    def testAnonymousGlobalEnums(self):
+        '''Checks availability of anonymous global enum items.'''
+        self.assertEqual(sample.AnonymousGlobalEnum_Value0, 0)
+        self.assertEqual(sample.AnonymousGlobalEnum_Value1, 1)
+
+    def testAnonymousClassEnums(self):
+        '''Checks availability of anonymous class enum items.'''
+        self.assertEqual(SampleNamespace.AnonymousClassEnum_Value0, 0)
+        self.assertEqual(SampleNamespace.AnonymousClassEnum_Value1, 1)
+
+    def testEnumTpPrintImplementation(self):
+        '''Without SbkEnum.tp_print 'print' returns the enum represented as an int.'''
+        tmpfile = os.tmpfile()
+        sys.stdout = tmpfile
+        print Event.ANY_EVENT
+        sys.stdout = sys.__stdout__
+        tmpfile.seek(0)
+        text = tmpfile.read().strip()
+        tmpfile.close()
+        self.assertEqual(text, str(Event.ANY_EVENT))
+        self.assertEqual(text, repr(Event.ANY_EVENT))
+
+
+class MyEvent(Event):
+    def __init__(self):
+        Event.__init__(self, Event.EventType(999))
+
+class OutOfBoundsTest(unittest.TestCase):
+    def testValue(self):
+        e = MyEvent()
+        self.assertEqual(repr(e.eventType()), '<enum-item sample.Event.EventType.#out of bounds# (999)>')
 
 class EnumOverloadTest(unittest.TestCase):
     '''Test case for overloads involving enums'''
