@@ -3,32 +3,42 @@
 #include "bucket.h"
 #include "collector.h"
 #include "complex.h"
+#include "ctorconvrule.h"
+#include "sbkdate.h"
 #include "derived.h"
 #include "echo.h"
 #include "functions.h"
 #include "implicitconv.h"
 #include "overloadsort.h"
+#include "handle.h"
 #include "injectcode.h"
 #include "list.h"
 #include "listuser.h"
 #include "mapuser.h"
 #include "modifications.h"
+#include "modified_constructor.h"
 #include "multiple_derived.h"
 #include "noimplicitconversion.h"
 #include "nondefaultctor.h"
+#include "objectmodel.h"
 #include "objecttype.h"
 #include "objecttypelayout.h"
+#include "objecttypereference.h"
+#include "objecttypeoperators.h"
 #include "objectview.h"
 #include "oddbool.h"
 #include "overload.h"
 #include "pairuser.h"
+#include "pen.h"
 #include "point.h"
+#include "pointf.h"
 #include "pointerholder.h"
 #include "polygon.h"
 #include "privatector.h"
 #include "privatedtor.h"
 #include "protected.h"
 #include "reference.h"
+#include "removednamespaces.h"
 #include "samplenamespace.h"
 #include "simplefile.h"
 #include "size.h"
@@ -38,3 +48,5 @@
 #include "virtualmethods.h"
 #include "voidholder.h"
 #include "valueandvirtual.h"
+#include "expression.h"
+#include "filter.h"
